<?php

namespace App\AdminModule\Presenters;

use \Nette\Application\UI\Form,
	\Nette\Image;

/**
 * Homepage presenter.
 */
class GalleryPresenter extends SecuredPresenter
{

	/** @var \App\Model\GalleryModel @inject */
	public $galleryModel;

	/** @var \App\Model\PhotoModel @inject */
	public $photoModel;

	private $galleryData;


	public function renderDefault()
	{
		$this->template->galleries = $this->galleryModel->findAll();
	}


	public function actionPhotos($id)
	{
		$this->galleryData = $this->galleryModel->findById($id);
	}


	public function renderPhotos()
	{
		$this->template->photos = $this->photoModel->findByGalleryId($this->galleryData->id);
	}


	protected function createComponentGalleryNameForm()
	{
		$form = new Form;
		$form->addText('name', 'Název')
			->setRequired('Není zadaný žádný název alba');
		$form->addTextarea('content', 'O albu');
		$form->addHidden('gallery_id', $this->galleryData->id);
		$form->addSubmit('submit', 'Uložit změny');
		$form->setDefaults(array(
			'name' => $this->galleryData->name,
			'content' => $this->galleryData->content
		));
		$form->onSuccess[] = callback($this, 'galleryNameFormSucceded');

		return $form;
	}


	public function galleryNameFormSucceded(Form $form)
	{
		$values = $form->getValues();
		$this->galleryModel->update($values->gallery_id, array('name' => $values->name, 'content' => $values->content));
		$this->redirect('this');
	}


	protected function createComponentPhotosForm()
	{
		$form = new Form;
		for ($i = 1; $i <= 5; $i++) {
			$form->addUpload('image_' . $i, 'Obrázek ' . $i)
				->addCondition(Form::FILLED)
				->addRule(Form::IMAGE, 'Obrázek musí být ve formátu JPEG, PNG nebo GIF.')
				->addRule(Form::MAX_FILE_SIZE, 'Maximální velikost souboru je 5 MB.', 5000 * 1024 /* v bytech */);
		}
		$form->addHidden('gallery_id', $this->galleryData->id);
		$form->addSubmit('submit', 'Nahrát fotografie')
			->setAttribute('class', 'btn btn-default');

		$form->onSuccess[] = callback($this, 'photosFormSucceded');

		return $form;
	}


	public function photosFormSucceded(Form $form)
	{
		$values = $form->getValues();
		for ($i = 1; $i <= 5; $i++) {
			$file = $form['image_' . $i]->getValue();
			if ($file->isOK()) {
				if (!is_dir(WWW_DIR . '/photos/' . $values->gallery_id)) {
					mkdir(WWW_DIR . '/photos/' . $values->gallery_id);
				}
				$filename = $file->getSanitizedName();
				$photo = $this->photoModel->add(array(
					'gallery_id' => $values->gallery_id,
					'created' => new \Nette\DateTime()
				));
				$dir = '/photos/' . $values->gallery_id . '/';
				$this->photoModel->update($photo->id, array(
					'name' => $photo->id . '_' . $filename,
					'path' => $dir . $photo->id . '_' . $filename
				));
				$file->move(WWW_DIR . $dir . $photo->id . '_' . $filename);

				$image = Image::fromFile(WWW_DIR . $dir . $photo->id . '_' . $filename);
				$image->resize(200, 200, Image::EXACT);
				$image->save(WWW_DIR . $dir . 'admin_thumb_' . $photo->id . '_' . $filename);
			}
		}
		$this->redirect('this');
	}


	protected function createComponentNewGalleryForm()
	{
		$form = $this->makeGalleryForm();
		$form->onSuccess[] = callback($this, 'newGalleryFormSucceded');
		return $form;
	}


	public function newGalleryFormSucceded(Form $form)
	{
		$values = $form->getValues();

		try {
			$this->galleryModel->add(array(
				'name' => $values->name,
				'content' => $values->content,
				'created' => new \Nette\DateTime()
			));
			$this->flashMessage('Album bylo úspěšně přidáno.', 'alert-success');
		} catch (\PDOException $e) {
			$this->flashMessage('Album se nepodařilo uložit.', 'alert-danger');
		}
		$this->redirect(':Admin:Gallery:');
	}


	private function makeGalleryForm($id = NULL)
	{
		$form = new Form;
		$form->addText('name', 'Název')
			->setRequired('Nevyplnili jste název alba');
		$form->addTextarea('content', 'Pár slov o albu');

		$form->addSubmit('submit', 'Uložit');

		return $form;
	}


	public function handleRemoveGallery($id)
	{
		if ($this->user->isInRole('superadmin')) {
			try {
				$photos = $this->photoModel->findByGalleryId($id);
				foreach ($photos as $photo) {
					if (file_exists(WWW_DIR . '/photos/' . $photo->gallery_id . '/' . $photo->name) && !is_dir(WWW_DIR . '/photos/' . $photo->gallery_id . '/' . $photo->name))
						unlink(WWW_DIR . '/photos/' . $photo->gallery_id . '/' . $photo->name);
					if (file_exists(WWW_DIR . '/photos/' . $photo->gallery_id . '/admin_thumb_' . $photo->name) && !is_dir(WWW_DIR . '/photos/' . $photo->gallery_id . '/admin_thumb_' . $photo->name))
						unlink(WWW_DIR . '/photos/' . $photo->gallery_id . '/admin_thumb_' . $photo->name);
					$this->photoModel->delete($photo->id);
				}
				if (is_dir(WWW_DIR . '/photos/' . $id))
					rmdir(WWW_DIR . '/photos/' . $id);
				$this->galleryModel->delete($id);
				$this->flashMessage('Album bylo úspěšně smazána.', 'alert-success');
			} catch (\PDOException $e) {
				$this->flashMessage('Album se nepodařilo smazat.', 'alert-danger');
			}
		}

		$this->redirect('this');
	}

	public function handleToggleVisibility($galleryId)
	{
		$galleryRow = $this->galleryModel->toggleVisibility($galleryId);

		if ($galleryRow->visible === 1) {
			$this->flashMessage('Galerie je nyní skrytá', 'alert-danger');
		} else {
			$this->flashMessage('Galerie je nyní viditelná', 'alert-success');
		}

		$this->redirect('this');
	}


	public function handleRemovePhoto($id)
	{
		$photo = $this->photoModel->findById($id);
		@unlink(WWW_DIR . '/photos/' . $photo->gallery_id . '/' . $photo->name);
		@unlink(WWW_DIR . '/photos/' . $photo->gallery_id . '/admin_thumb_' . $photo->name);
		$this->photoModel->delete($id);
		$this->redirect(':Admin:Gallery:photos', $photo->gallery_id);
	}

}
